<?php
/*
Plugin Name: Plazes Map
Version: 0.2
Plugin URI: http://blog.tijs.org/archives/2005/11/09/plazes-google-map-wordpress-plugin-released/
Description: Allows you to grab your current Plazes (plazes.com) location given your Plazes username and password and publish a Google map with the result.
Author: Tijs Teulings
Author URI: http://www.tijs.org/

built with PlazesWhereAmI by Peter Rukavina (http://ruk.ca/)

Copyright (c) 2005
Released under the GPL license
http://www.gnu.org/licenses/gpl.txt
*/

/*
 usage: just call the current_location function somewhere in your
        Wordpress template, and style the output using CSS. Don't forget to enable
        the plugin on the wordpress admin page.
*/

/**
  * Include your Google API key.
  * To use Google maps on your site you need to request a key for your own site (http://www.google.com/apis/maps/signup.html)
  */
$google_api_key = 'ABQIAAAAxvx2RdWgkgaWwmUjl1M2JRQgzzxsOq_IZFFK3B8S1XLcGM3PIBTDjsPSrD8N0vRCgmwd_guRm1w2ew';

/**
  * Include XML-RPC functionality. 
  * We depend on the presence of the XML-RPC for PHP ({@link http://phpxmlrpc.sourceforge.net/}).
  * You can install this anywhere; just ensure that you specify the correct location in the include below.
  */
include("xmlrpc.inc");

/**
  * The plugin call
  * This is our main function that you call from within a Wordpress template. Calling it with just a username 
  * and a plazes password is fine, the rest of the options are... ehmm optional.
  */
function current_location(
	$username,  						# your plazes username
  	$passwordPlain,  					# your plazes password
	$width = 430, 						# width of the google map
	$height = 200,						# height of the google map
	$zoom = 5,							# set the initial zoom level
	$maptype = G_SATELLITE_TYPE 	# set maptype to G_SATELLITE_TYPE or G_MAP_TYPE
	
) {

	// Calculate MD5 hash of the string PLAZES plus the password.
	$passwordMD5 = md5("PLAZES" . $passwordPlain);

	// Now that we've got the MD5 hash, send an XML-RPC request to the Plazes XML-RPC server and dump the result.
	if ($location = TalktoPlazes($username, $passwordMD5)) {
		// Some simple error handling
		if (!empty($location['errorcode'])) {
			// Plazes returns an o for offline
			if ($location['errorcode'] == 'o') {
				echo "<div id=\"map\" style=\"width: {$width}px; height: {$height}px\"><p>I'm plazeless (i.e. offline)</p></div>";
			} else {
				echo "<div id=\"map\" style=\"width: {$width}px; height: {$height}px\"><p>Error {$location['errorcode']}: {$location['error']}</p></div>";
			}
		} else {

			// if we got this far we probably have data...
			$longitude 	= $location['plazelon'];
			$latitude 	= $location['plazelat'];
			$name 		= $location['plazename'];
			$url 			= $location['plazeurl'];

			$city 		= $location['plazecity'];
			$country 	= $location['plazecountry'];
	
			$output = <<<EOD
<div id="map" style="width: {$width}px; height: {$height}px"></div>
<script type="text/javascript">
//<![CDATA[
function ShowMeTheMap() {
	if (GBrowserIsCompatible()) {
		// Create our tiny marker icon
		var icon = new GIcon();
		icon.image = "http://labs.google.com/ridefinder/images/mm_20_red.png";
		icon.shadow = "http://labs.google.com/ridefinder/images/mm_20_shadow.png";
		icon.iconSize = new GSize(12, 20);
		icon.shadowSize = new GSize(22, 20);
		icon.iconAnchor = new GPoint(6, 20);
		icon.infoWindowAnchor = new GPoint(5, 1);

		// Center the map on Palo Alto
		var map = new GMap(document.getElementById("map"));
		map.addControl(new GSmallMapControl());
		map.addControl(new GMapTypeControl());
		map.setMapType(G_SATELLITE_TYPE);
		map.centerAndZoom(new GPoint({$longitude}, {$latitude}), {$zoom});

		// Creates one of our tiny markers at the given point
		function createMarker(point) {
		 var marker = new GMarker(point, icon);
		 map.addOverlay(marker);
		 GEvent.addListener(marker, "click", function() {
		   marker.openInfoWindowHtml("<div style='width: 160px; height: 20px; font: 12px verdana, arial;'>I'm at <a href='{$url}'>{$name}</a><br />{$city}, {$country}</div>");
		 });
		}

		// Place the icon on the map
		var center = map.getCenterLatLng();
		 createMarker(new GPoint(center.x,center.y));
	}
}

window.onload = ShowMeTheMap;

//]]>
</script>
EOD;
	
			echo $output;
			
		}
		
	} else {
	
		echo "<div id=\"map\" style=\"width: {$width}px; height: {$height}px\"><p>Error: Plazes server unavailable.</p></div>";
	
	}
}

/**
  * Get current Plazes location.
  * Allows you to grab your current Plazes (plazes.com) location given your Plazes username and password.
  * @package PlazesWhereAmIPHP
  * @version 0.9
  * @author Peter Rukavina <peter@rukavina.net>
  * @author Olle Jonsson <olle@olleolleolle.dk>
  * @copyright Reinvented Inc., 2005
  * @license http://creativecommons.org/licenses/by-sa/2.0/ca
  */

/**
  * Talk to the Plazes server.
  * Sends an XML-RPC request to the Plazes server to request current location.
  * @param string $username your Plazes username
  * @param string $password an MD5 hash of the string PLAZES plus your Plazes password
  * @return array information about Plazes location
  */
function TalktoPlazes($username, $passwordMD5) {

	$c=new xmlrpc_client("/xmlrpc/whereami.php", "beta.plazes.com", 80);

	$params = array(
			new xmlrpcval($username, "string"),
			new xmlrpcval($passwordMD5, "string")
			);
	
	$f = new xmlrpcmsg('plazes.whereami', $params);
	
	$r = $c->send($f);
	$v = $r->value();

	if ($r->faultCode()) {
		$returnArray = array('error'=>$r->faultString(),'errorcode'=>$r->faultCode());
		return $returnArray;
	}
	else {
		$PlazesData = php_xmlrpc_decode($v);
		return $PlazesData;
	}
}

// This just echoes the Google maps Javascript code
function hello_google() {
	global $google_api_key;
	echo "<script src=\"http://maps.google.com/maps?file=api&v=1&key=$google_api_key\" type=\"text/javascript\"></script>";
}

// Now we set that function up to execute when the wp_head action is called
if (function_exists('add_action')) {
	add_action('wp_head', 'hello_google');
}

?>